@@ -128,23 +128,19 @@ class ImpalaAdapter(SQLAdapter):
 
         relations = []
         for row in results:
-            if len(row) != 1:
+            if len(row) != 2:
                 raise dbt.exceptions.RuntimeException(
                     f'Invalid value from "show table extended ...", '
                     f'got {len(row)} values, expected 4'
                 )
             _identifier = row[0]
-
-            # TODO: the following is taken from spark, needs to see what is there in impala
-            # TODO: this modification is not really right, need fix
-            rel_type = RelationType.View \
-                if 'view' in _identifier else RelationType.Table
+            _rel_type   = row[1]
 
             relation = self.Relation.create(
                 database=schema_relation.database,
                 schema=schema_relation.schema,
                 identifier=_identifier,
-                type=rel_type,
+                type=_rel_type,
                 information=_identifier,
             )
             relations.append(relation)
@@ -163,9 +159,17 @@ class ImpalaAdapter(SQLAdapter):
             columns = self.parse_columns_from_information(cached_relation)
 
         # execute the macro and parse the data
-        if not columns:
-            rows: List[agate.Row] = super().get_columns_in_relation(relation)
-            columns = self.parse_describe_extended(relation, rows)
+        if not columns:       
+            try:
+                rows: List[agate.Row] = super().get_columns_in_relation(relation)
+                columns = self.parse_describe_extended(relation, rows)
+            except dbt.exceptions.RuntimeException as e:
+                # impala would throw error when table doesn't exist
+                errmsg = getattr(e, "msg", "")
+                if "Table or view not found" in errmsg or "NoSuchTableException" in errmsg:
+                    pass
+                else:
+                    raise e
 
         return columns
 
@@ -391,3 +395,7 @@ class ImpalaAdapter(SQLAdapter):
 
             yield as_dict
  
+    def timestamp_add_sql(self, add_to: str, number: int = 1, interval: str = "hour") -> str:
+        # We override this from base dbt adapter because impala doesn't need to escape interval 
+        # duration string like postgres/redshift.
+        return f"{add_to} + interval {number} {interval}"
